#include "uRTCLib.h"
#include <Servo.h>
#include <LiquidCrystal_I2C.h>
#include <Keypad.h>


const byte ROWS = 4; // Four rows

const byte COLS = 4; // Three columns

// Define the Keymap
char keys[ROWS][COLS] = {
  {'1','2','3','A'},
  {'4','5','6','B'},
  {'7','8','9','C'},
  {'*','0','#','D'}
};


// Connect keypad ROW0, ROW1, ROW2 and ROW3 to these Arduino pins.
byte rowPins[ROWS] = { 9, 8, 7, 6 };

// Connect keypad COL0, COL1 and COL2 to these Arduino pins.
byte colPins[COLS] = { 5, 4, 3, 2 };

//  Create the Keypad
Keypad kpd = Keypad( makeKeymap(keys), rowPins, colPins, ROWS, COLS );

uRTCLib rtc(0x68);

Servo servo_test;      //servo object for the connected servo  

LiquidCrystal_I2C lcd(0x27, 16, 2);

int t1 = 0, t2 = 0, t3 = 0, t4;

boolean feed = false; // condition for feeding time

char key;

int r[6];

void setup() { 
  t4 = -1;

  servo_test.attach(10);   // attach the signal pin of servo to pin10 of arduino

  URTCLIB_WIRE.begin();
  rtc.set(00, 00, 13, 1, 22, 5, 23);

  pinMode(13, INPUT_PULLUP);

  lcd.init();
  lcd.backlight();

  servo_test.write(55); 

  Serial.begin(9600);

} 

void loop() { 
  lcd.setCursor(0,0);

  int buttonPress;

  buttonPress = digitalRead(13);


  if (buttonPress == 0)
    setFeedingTime();

  rtc.refresh();
  String message = "Time: ";
  String h = "";
  String m = "";
  String s = "";

  h = rtc.hour();
  m = rtc.minute();
  s = rtc.second();

  message = message + h;
  message = message + ":";
  message = message + m;
  message = message + ":";
  message = message + s;
  message = message + "  ";
  
  lcd.print(message);

  t1 = h.charAt(0)-48;
  if (h.length() == 2) {
    t2 = h.charAt(1)-48;
  }

  t3 = m.charAt(0)-48;

  if (m.length() == 2) {
    t4 = m.charAt(1)-48;
 }

  lcd.setCursor(0,1);

  lcd.print("Date: ");
  lcd.print(rtc.year());
  lcd.print('/');
  lcd.print(rtc.month());
  lcd.print('/');
  lcd.print(rtc.day());

  if (t2 == 0) {
    if (t1 == r[1] && feed == true) {
      if (t4 == -1) {
      if (t3 == r[3]) {
        servo_test.write(150);                   //command to rotate the servo to the specified angle 

        delay(10000);   

        servo_test.write(55);

        feed=false;
      }
    } else {
      if (t3 == r[2] && t4 == r[3]) {
        servo_test.write(150);                   //command to rotate the servo to the specified angle 

        delay(10000);   

        servo_test.write(55);

        t4 = -1;

        feed=false;
      }
    }
    }
  } else {
    if (t1 == r[0] && t2 == r[1] && feed == true) {
      if (t4 == -1) {
        if (t3 == r[3]) {
          servo_test.write(150);                   //command to rotate the servo to the specified angle 

          delay(10000);   

          servo_test.write(55);

          feed=false;
        }
      } else {
        if (t3 == r[2] && t4 == r[3]) {
          servo_test.write(150);                   //command to rotate the servo to the specified angle 

          delay(10000);   

          servo_test.write(55);

          t4 = -1;

          feed=false;
        }
      }
    }
  }
}       


void setFeedingTime() {
  feed = true;

  int i=0;

  lcd.clear();

  lcd.setCursor(0,0);

  lcd.print("Set feeding Time");
  
  delay(400);

  lcd.clear();

  lcd.print("HH:MM");

  lcd.setCursor(0,1);
  int j = 0;

  while(1) {

    key = kpd.getKey(); 

    if(key!=NO_KEY) {

      lcd.setCursor(j,1);

      lcd.print(key);

      r[i] = key-48;

      i++;
      j++;

      if (j==2) {
        lcd.print(":"); j++;
      }

      delay(500);
    }


    if (key == 'D') {
      key=0;
      lcd.clear(); 
      break;
    }
  }
}
